@@ -5,7 +5,7 @@ from typing import Callable, Type
 from logos_cdi.abstract import AbstractContainer, R
 from logos_cdi.builder import ContainerBuilder
 from logos_cdi.container import CacheContainer, ContainerGroup, Container
-from logos_cdi.resource import Parameter
+from logos_cdi.resource import Parameter, Group
 
 
 class Module(AbstractContainer):
@@ -46,8 +46,12 @@ class Application(AbstractContainer):
     @property
     def container(self):
         if not self._container:
+            resources = {
+                'application': Parameter(self),
+                'modules': Group(r'module:(?P<name>[\w+.]*)', resolve_resources=True)
+            }
             containers = [
-                Container({'application': Parameter(self)})
+                Container(resources)
             ]
             for module_path in self.modules: #type: str
                 if module_path.startswith('zip://'):
@@ -56,10 +60,12 @@ class Application(AbstractContainer):
                     module = zip_module.load_module(path)
                     if hasattr(module, '__container__'):
                         containers.append(getattr(module, '__container__'))
+                    resources[f'module:{path}'] = Parameter(module)
                 else:
                     module = import_module(module_path)
                     if hasattr(module, '__container__'):
                         containers.append(getattr(module, '__container__'))
+                    resources[f'module:{module_path}'] = Parameter(module)
             self._container = CacheContainer('application', ContainerGroup(containers))
         return CacheContainer('runtime', self._container)
 
